@@ -42,11 +42,11 @@
 #define HTML_LOG            0
 
 #define POKERTH_VERSION_MAJOR	1
-#define POKERTH_VERSION_MINOR	0
+#define POKERTH_VERSION_MINOR	01
 #define POKERTH_VERSION			((POKERTH_VERSION_MAJOR << 8) | POKERTH_VERSION_MINOR)
 
 #define POKERTH_BETA_REVISION	0
-#define POKERTH_BETA_RELEASE_STRING	 "1.0"
+#define POKERTH_BETA_RELEASE_STRING	 "1.0.1"
 
 #define SQLITE_LOG_VERSION		1
 
