@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,12 +14,26 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 #include "chattools.h"
 #include "session.h"
 #include "configfile.h"
 #include "gametablestylereader.h"
 #include "gamelobbydialogimpl.h"
+#include "soundevents.h"
 #include <iostream>
 
 
@@ -30,7 +44,6 @@ ChatTools::ChatTools(QLineEdit* l, ConfigFile *c, ChatType ct, QTextBrowser *b,
 {
 	myNick = QString::fromUtf8(myConfig->readConfigString("MyName").c_str());
 	ignoreList = myConfig->readConfigStringList("PlayerIgnoreList");
-
 }
 
 ChatTools::~ChatTools()
@@ -83,7 +96,7 @@ void ChatTools::receiveMessage(QString playerName, QString message, bool pm)
 			tempMsg = QString("<span style=\"font-weight:bold; color:red;\">"+message+"</span>");
 			//play beep sound only in INET-lobby-chat
 			if(myLobby->isVisible() && myConfig->readConfigInt("PlayLobbyChatNotification")) {
-				myLobby->getMyW()->getMySDLPlayer()->playSound("lobbychatnotify",0);
+				myLobby->getMyW()->getMySoundEventHandler()->playSound("lobbychatnotify",0);
 			}
 		} else if(message.contains(myNick, Qt::CaseInsensitive)) {
 
@@ -93,7 +106,7 @@ void ChatTools::receiveMessage(QString playerName, QString message, bool pm)
 				//play beep sound only in INET-lobby-chat
 				//						TODO dont play when message is from yourself
 				if(myLobby->isVisible() && myConfig->readConfigInt("PlayLobbyChatNotification")) {
-					myLobby->getMyW()->getMySDLPlayer()->playSound("lobbychatnotify",0);
+					myLobby->getMyW()->getMySoundEventHandler()->playSound("lobbychatnotify",0);
 				}
 			}
 			break;
@@ -154,6 +167,8 @@ void ChatTools::receiveMessage(QString playerName, QString message, bool pm)
 
 		if(!nickFoundOnIgnoreList) {
 
+			tempMsg = checkForEmotes(tempMsg);
+
 			if(message.indexOf(QString("/me "))==0) {
 				myTextBrowser->append(tempMsg.replace("/me ","<i>*"+playerName+" ")+"</i>");
 			} else if(pm == true) {
@@ -313,3 +328,45 @@ unsigned ChatTools::parsePrivateMessageTarget(QString &chatText)
 	return playerId;
 }
 
+QString ChatTools::checkForEmotes(QString msg)
+{
+
+	msg.replace("0:-)", "<img src=\":emotes/emotes/face-angel.png\" />");
+	msg.replace("X-(", "<img src=\":emotes/emotes/face-angry.png\" />");
+	msg.replace("B-)", "<img src=\":emotes/emotes/face-cool.png\" />");
+	msg.replace("8-)", "<img src=\":emotes/emotes/face-cool.png\" />");
+	msg.replace(":'(", "<img src=\":emotes/emotes/face-crying.png\" />");
+	msg.replace("&gt;:-)", "<img src=\":emotes/emotes/face-devilish.png\" />");
+	msg.replace(":-[", "<img src=\":emotes/emotes/face-embarrassed.png\" />");
+	msg.replace(":-*", "<img src=\":emotes/emotes/face-kiss.png\" />");
+	msg.replace(":-))", "<img src=\":emotes/emotes/face-laugh.png\" />");
+	msg.replace(":))", "<img src=\":emotes/emotes/face-laugh.png\" />");
+	msg.replace(":-|", "<img src=\":emotes/emotes/face-plain.png\" />");
+	msg.replace(":-P", "<img src=\":emotes/emotes/face-raspberry.png\" />");
+	msg.replace(":-p", "<img src=\":emotes/emotes/face-raspberry.png\" />");
+	msg.replace(":-(", "<img src=\":emotes/emotes/face-sad.png\" />");
+	msg.replace(":(", "<img src=\":emotes/emotes/face-sad.png\" />");
+	msg.replace(":-&", "<img src=\":emotes/emotes/face-sick.png\" />");
+	msg.replace(":-D", "<img src=\":emotes/emotes/face-smile-big.png\" />");
+	msg.replace(":D", "<img src=\":emotes/emotes/face-smile-big.png\" />");
+	msg.replace(":-!", "<img src=\":emotes/emotes/face-smirk.png\" />");
+	msg.replace(":-0", "<img src=\":emotes/emotes/face-surprise.png\" />");
+	msg.replace(":-O", "<img src=\":emotes/emotes/face-surprise.png\" />");
+	msg.replace(":-o", "<img src=\":emotes/emotes/face-surprise.png\" />");
+	msg.replace(":-/", "<img src=\":emotes/emotes/face-uncertain.png\" />");
+
+	//prevent links from beeing broken by :/ emoticon
+	if(!msg.contains("http://") && !msg.contains("https://")) {
+		msg.replace(":/", "<img src=\":emotes/emotes/face-uncertain.png\" />");
+	}
+
+	msg.replace(";-)", "<img src=\":emotes/emotes/face-wink.png\" />");
+	msg.replace(";)", "<img src=\":emotes/emotes/face-wink.png\" />");
+	msg.replace(":-S", "<img src=\":emotes/emotes/face-worried.png\" />");
+	msg.replace(":-s", "<img src=\":emotes/emotes/face-worried.png\" />");
+	msg.replace(":-)", "<img src=\":emotes/emotes/face-smile.png\" />");
+	msg.replace(":)", "<img src=\":emotes/emotes/face-smile.png\" />");
+
+	return msg;
+}
+
