@@ -202,15 +202,21 @@ gameLobbyDialogImpl::gameLobbyDialogImpl(startWindowImpl *parent, ConfigFile *c)
 	nickListPlayerInfoSubMenu->addAction(nickListPlayerInGameInfo);
 	nickListOpenPlayerStats1 = new QAction(QIcon(":/gfx/view-statistics.png"), tr("Show player stats"), nickListContextMenu);
 	nickListContextMenu->addAction(nickListOpenPlayerStats1);
+	nickListAdminSubMenu = nickListContextMenu->addMenu(tr("Admin action ..."));
+	nickListAdminTotalKickBan = new QAction(tr("Total kickban"), nickListAdminSubMenu);
+	nickListAdminSubMenu->addAction(nickListAdminTotalKickBan);
 
 	connectedPlayersListPlayerInfoSubMenu = new QMenu();
 	nickListOpenPlayerStats2 = new QAction(QIcon(":/gfx/view-statistics.png"), tr("Show player stats"), nickListContextMenu);
 	connectedPlayersListPlayerInfoSubMenu->addAction(nickListOpenPlayerStats2);
+	connectedPlayersListPlayerInfoSubMenu = new QMenu();
 
 	gameListContextMenu = new QMenu();
 	gameListReportBadGameNameAction = new QAction(QIcon(":/gfx/emblem-important.png"), tr("Report inappropriate game name"), gameListContextMenu);
 	gameListContextMenu->addAction(gameListReportBadGameNameAction);
-
+	gameListAdminSubMenu = gameListContextMenu->addMenu(tr("Admin action ..."));
+	gameListAdminCloseGame = new QAction(tr("Close game"), gameListAdminSubMenu);
+	gameListAdminSubMenu->addAction(gameListAdminCloseGame);
 
 	connect( pushButton_CreateGame, SIGNAL( clicked() ), this, SLOT( createGame() ) );
 	connect( pushButton_JoinGame, SIGNAL( clicked() ), this, SLOT( joinGame() ) );
@@ -240,6 +246,8 @@ gameLobbyDialogImpl::gameLobbyDialogImpl(startWindowImpl *parent, ConfigFile *c)
 	connect( nickListOpenPlayerStats2, SIGNAL(triggered()), this, SLOT( openPlayerStats2() ));
 	connect( lineEdit_searchForPlayers, SIGNAL(textChanged(QString)),this, SLOT(searchForPlayerRegExpChanged()));
 	connect( gameListReportBadGameNameAction, SIGNAL(triggered()), this, SLOT( reportBadGameName()));
+	connect( gameListAdminCloseGame, SIGNAL(triggered()), this, SLOT( adminActionCloseGame() ));
+	connect( nickListAdminTotalKickBan, SIGNAL(triggered()), this, SLOT( adminActionTotalKickBan() ));
 
 	lineEdit_searchForPlayers->installEventFilter(this);
 	lineEdit_ChatInput->installEventFilter(this);
@@ -1675,7 +1683,6 @@ void gameLobbyDialogImpl::showNickListContextMenu(QPoint p)
 			nickListIgnorePlayerAction->setText(tr("Ignore player ..."));
 		}
 
-
 		unsigned gameIdOfPlayer = mySession->getGameIdOfPlayer(playerUid);
 		QString playerInGameInfoString;
 		if(gameIdOfPlayer) {
@@ -1685,6 +1692,15 @@ void gameLobbyDialogImpl::showNickListContextMenu(QPoint p)
 		}
 		nickListPlayerInGameInfo->setText(playerInGameInfoString);
 
+		//prevent admin to total kickban himself
+		if(playerUid == mySession->getClientUniquePlayerId()) {	nickListAdminTotalKickBan->setDisabled(true); }
+		else { nickListAdminTotalKickBan->setEnabled(true);	}
+
+//		check for admin	and remove admin actions for non-admins
+		if(!mySession->getClientPlayerInfo(mySession->getClientUniquePlayerId()).isAdmin) {
+			nickListContextMenu->removeAction(nickListAdminSubMenu->menuAction());
+		}
+
 		//popup a little more to the right to avaoid double click action
 		QPoint tempPoint = p;
 		tempPoint.setX(p.x()+5);
@@ -1695,6 +1711,17 @@ void gameLobbyDialogImpl::showNickListContextMenu(QPoint p)
 void gameLobbyDialogImpl::showGameListContextMenu(QPoint p)
 {
 	if(myGameListModel->rowCount() && myGameListSelectionModel->currentIndex().isValid()) {
+
+		assert(mySession);
+		unsigned selectedGameId = myGameListSelectionModel->selectedRows().first().data(Qt::UserRole).toUInt();
+		if(selectedGameId == mySession->getClientCurrentGameId()) { gameListAdminCloseGame->setDisabled(true); }
+		else { gameListAdminCloseGame->setEnabled(true); }
+
+//		check for admin	and remove admin actions for non-admins
+		if(!mySession->getClientPlayerInfo(mySession->getClientUniquePlayerId()).isAdmin) {
+			gameListContextMenu->removeAction(gameListAdminSubMenu->menuAction());
+		}
+
 		//popup a little more to the right to avaoid double click action
 		QPoint tempPoint = p;
 		tempPoint.setX(p.x()+5);
@@ -2158,9 +2185,8 @@ void gameLobbyDialogImpl::closeAllChildDialogs()
 void gameLobbyDialogImpl::reportBadGameName()
 {
 	assert(mySession);
-	QItemSelectionModel *selection = treeView_GameList->selectionModel();
-	if (selection->hasSelection()) {
-		unsigned gameId = selection->selectedRows().first().data(Qt::UserRole).toUInt();
+	if (myGameListSelectionModel->hasSelection()) {
+		unsigned gameId = myGameListSelectionModel->selectedRows().first().data(Qt::UserRole).toUInt();
 		GameInfo info(mySession->getClientGameInfo(gameId));
 
 		int ret = MyMessageBox::question(this, tr("PokerTH - Question"),
@@ -2171,3 +2197,36 @@ void gameLobbyDialogImpl::reportBadGameName()
 		}
 	}
 }
+
+
+void gameLobbyDialogImpl::adminActionCloseGame()
+{
+	assert(mySession);
+	if (myGameListSelectionModel->hasSelection()) {
+		unsigned gameId = myGameListSelectionModel->selectedRows().first().data(Qt::UserRole).toUInt();
+		GameInfo info(mySession->getClientGameInfo(gameId));
+
+		int ret = MyMessageBox::question(this, tr("PokerTH - Question"),
+										 tr("Are you sure you want to close the game:\n\"%1\"?").arg(QString::fromUtf8(info.name.c_str())), QMessageBox::Yes | QMessageBox::No);
+
+		if (ret == QMessageBox::Yes) {
+			mySession->adminActionCloseGame(gameId);
+		}
+	}
+}
+
+void gameLobbyDialogImpl::adminActionTotalKickBan()
+{
+	assert(mySession);
+	if (myNickListSelectionModel->hasSelection()) {
+		unsigned playerId = myNickListSelectionModel->selectedRows().first().data(Qt::UserRole).toUInt();
+		PlayerInfo info(mySession->getClientPlayerInfo(playerId));
+
+		int ret = MyMessageBox::question(this, tr("PokerTH - Question"),
+										 tr("Are you sure you want to total kickban the player: \"%1\"?").arg(QString::fromUtf8(info.playerName.c_str())), QMessageBox::Yes | QMessageBox::No);
+
+		if(ret == QMessageBox::Yes) {
+			mySession->adminActionBanPlayer(playerId);
+		}
+	}
+}
