@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,6 +14,19 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 #include "guilog.h"
 
@@ -735,15 +748,15 @@ void guiLog::exportLogPdbToTxt(QString fileStringPdb, QString exportFileString)
 
 }
 
-void guiLog::showLog(QString fileStringPdb, QTextBrowser *tb_tmp)
+void guiLog::showLog(QString fileStringPdb, QTextBrowser *tb_tmp, int uniqueGameID)
 {
 	tb = tb_tmp;
 	tb->clear();
-	exportLog(fileStringPdb,3);
+	exportLog(fileStringPdb,3,uniqueGameID);
 
 }
 
-int guiLog::exportLog(QString fileStringPdb,int modus)
+int guiLog::exportLog(QString fileStringPdb,int modus,int uniqueGameID_req)
 {
 	bool neu = false;
 
@@ -857,7 +870,11 @@ int guiLog::exportLog(QString fileStringPdb,int modus)
 		log_string = "";
 
 		// read game
-		sql = "SELECT * FROM Game";
+		if(uniqueGameID_req > 0) {
+			sql = "SELECT * FROM Game WHERE UniqueGameID=" + boost::lexical_cast<std::string>(uniqueGameID_req);
+		} else {
+			sql = "SELECT * FROM Game";
+		}
 		if(sqlite3_get_table(mySqliteLogDb,sql.c_str(),&results.result_Game,&nRow_Game,&nCol_Game,&errmsg) != SQLITE_OK) {
 			cout << "Error in statement: " << sql.c_str() << "[" << errmsg << "]." << endl;
 			cleanUp(results, mySqliteLogDb);
@@ -1492,6 +1509,50 @@ int guiLog::exportLog(QString fileStringPdb,int modus)
 
 }
 
+QList<int> guiLog::getGameList(QString fileStringPdb)
+{
+
+	result_struct results;
+	results.result_Session = 0;
+	results.result_Game = 0;
+	results.result_Player = 0;
+	results.result_Hand = 0;
+	results.result_Hand_ID = 0;
+	results.result_Action = 0;
+
+	int nRow_Game=0;
+	int nCol_Game=0;
+	char *errmsg = 0;
+	int game_ctr = 0;
+	int i = 0;
+
+	QList<int> gameList;
+
+	// open sqlite log-db
+	sqlite3 *mySqliteLogDb;
+	sqlite3_open(fileStringPdb.toStdString().c_str(), &mySqliteLogDb);
+	if( mySqliteLogDb != 0 ) {
+
+		string sql = "SELECT * FROM Game";
+		if(sqlite3_get_table(mySqliteLogDb,sql.c_str(),&results.result_Game,&nRow_Game,&nCol_Game,&errmsg) != SQLITE_OK) {
+			cout << "Error in statement: " << sql.c_str() << "[" << errmsg << "]." << endl;
+		} else {
+			for(game_ctr=1; game_ctr<=nRow_Game; game_ctr++) {
+				for(i=0; i<nCol_Game; i++) {
+					if(boost::lexical_cast<std::string>(results.result_Game[i]) == "UniqueGameID") {
+						gameList.append(boost::lexical_cast<int>(results.result_Game[i+nCol_Game*game_ctr]));
+					}
+				}
+			}
+		}
+	}
+
+	cleanUp(results, mySqliteLogDb);
+
+	return gameList;
+
+}
+
 void guiLog::cleanUp(result_struct &results, sqlite3 *mySqliteLogDb)
 {
 
