@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,16 +14,36 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 #include "internetgamelogindialogimpl.h"
 #include "configfile.h"
 #include <tools.h>
 #include <QtCore>
+#include <QtGui>
 
 internetGameLoginDialogImpl::internetGameLoginDialogImpl(QWidget *parent, ConfigFile *c) :
 	QDialog(parent), myConfig(c)
 {
 	setupUi(this);
+	this->installEventFilter(this);
+
+	//html stuff
+	QString createAccount(QString("<a href='http://create-gaming-account.pokerth.net'>%1</a>").arg(tr("Create new user account")));
+	label_createAnAccount->setText(createAccount);
+
 
 	connect(groupBox_reguser, SIGNAL(toggled(bool)), this, SLOT(regUserToggled(bool)));
 	connect(checkBox_guest, SIGNAL(toggled(bool)), this, SLOT(guestUserToggled(bool)));
@@ -142,3 +162,27 @@ void internetGameLoginDialogImpl::okButtonCheck()
 	}
 }
 
+
+bool internetGameLoginDialogImpl::eventFilter(QObject *obj, QEvent *event)
+{
+#ifdef ANDROID
+	QKeyEvent *keyEvent = static_cast<QKeyEvent*>(event);
+
+	//androi changes for return key behavior (hopefully useless from necessitas beta2)
+	if (event->type() == QEvent::KeyPress && keyEvent->key() == Qt::Key_Return) {
+		if(lineEdit_username->hasFocus()) {
+			lineEdit_password->setFocus();
+		}
+		if(lineEdit_password->hasFocus()) {
+			QTimer::singleShot(1000, this, SLOT(clickLoginButton()));
+		}
+		event->ignore();
+		return false;
+	} else {
+		// pass the event on to the parent class
+		return QDialog::eventFilter(obj, event);
+	}
+#else
+	return QDialog::eventFilter(obj, event);
+#endif
+}
