@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,44 +14,47 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 #include "sdlplayer.h"
 
-#ifndef ANDROID
 #if (defined __APPLE__)
 #include <SDL.h>
 #else
 #include <SDL/SDL.h>
 #endif
-#endif
 
 using namespace std;
 
 SDLPlayer::SDLPlayer(ConfigFile *c)
-#ifndef ANDROID
-	: soundData(NULL), currentChannel(0) , audioEnabled(0), myConfig(c)
-#endif
+	: sound(NULL), soundData(NULL), currentChannel(0), audioEnabled(FALSE), myConfig(c)
 {
-#ifndef ANDROID
+	myAppDataPath = QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str());
 	SDL_Init(SDL_INIT_AUDIO);
 	initAudio();
-
-	myAppDataPath = QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str());
-#endif
 }
 
 
 SDLPlayer::~SDLPlayer()
 {
-#ifndef ANDROID
 	closeAudio();
 	SDL_Quit();
-#endif
 }
 
 void SDLPlayer::initAudio()
 {
-#ifndef ANDROID
 	if (!audioEnabled && myConfig->readConfigInt("PlaySoundEffects")) {
 		int		audio_rate = 44100;
 		Uint16	audio_format = AUDIO_S16; /* 16-bit stereo */
@@ -59,17 +62,17 @@ void SDLPlayer::initAudio()
 		int		audio_buffers = 4096;
 		sound = NULL;
 
-		if(Mix_OpenAudio(audio_rate, audio_format, audio_channels, audio_buffers) == 0) {
+		if( Mix_OpenAudio(audio_rate, audio_format, audio_channels, audio_buffers) == 0) {
 			Mix_QuerySpec(&audio_rate, &audio_format, &audio_channels);
 			audioEnabled = 1;
+		} else {
+			qDebug() << "Mix_OpenAudio() was not successfull, no sound possible :(";
 		}
 	}
-#endif
 }
 
 void SDLPlayer::playSound(string audioString, int playerID)
 {
-#ifndef ANDROID
 	if(audioEnabled && myConfig->readConfigInt("PlaySoundEffects")) {
 
 		QFile myFile(myAppDataPath + "sounds/default/" + QString::fromStdString(audioString)+".wav");
@@ -124,15 +127,11 @@ void SDLPlayer::playSound(string audioString, int playerID)
 			break;
 			}
 
-//			audioDone();
-
 			QDataStream in(&myFile);
 			soundData = new Uint8[(int)myFile.size()];
 			in.readRawData( (char*)soundData, (int)myFile.size() );
-
 			sound = Mix_QuickLoad_WAV(soundData);
 
-
 			// set channel 0 to settings volume
 			Mix_Volume(-1,myConfig->readConfigInt("SoundVolume")*10);
 
@@ -143,37 +142,25 @@ void SDLPlayer::playSound(string audioString, int playerID)
 			}
 			currentChannel = Mix_PlayChannel(-1, sound,0);
 		}
-		// 	else cout << "could not load " << audioString << ".wav" << endl;
-
-		//test
-		//	audioDone();
-		//	sound = Mix_LoadWAV( QString(QString::fromStdString(audioString)+QString(".wav")).toStdString().c_str() );
-		//	currentChannel = Mix_PlayChannel(-1, sound,0);
-
 	}
-#endif
 }
 
-void SDLPlayer::audioDone()
+void SDLPlayer::closeAudio()
 {
-#ifndef ANDROID
 	if(audioEnabled) {
 		Mix_HaltChannel(currentChannel);
 		Mix_FreeChunk(sound);
 		sound = NULL;
 		delete[] soundData;
 		soundData = NULL;
-	}
-#endif
-}
-
-void SDLPlayer::closeAudio()
-{
-#ifndef ANDROID
-	if(audioEnabled) {
-		audioDone();
 		Mix_CloseAudio();
+		qDebug() << "Mix_CloseAudio()";
 		audioEnabled = false;
 	}
-#endif
+}
+
+void SDLPlayer::reInit()
+{
+	closeAudio();
+	initAudio();
 }
