@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,6 +14,19 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 #include <QtCore>
 
@@ -23,15 +36,13 @@
 #include "configfile.h"
 #include <string>
 
-#ifndef ANDROID
 #ifdef __APPLE__
 #include <SDL_mixer.h>
 #else
 #include <SDL/SDL_mixer.h>
 #endif
-#endif
 
-// struct Mix_Chunk;
+struct Mix_Chunk;
 
 /**
 	@author FThauer FHammer <webmaster@pokerth.net>
@@ -47,21 +58,16 @@ public:
 
 	void initAudio();
 	void playSound(std::string, int playerID);
-	void audioDone();
 	void closeAudio();
+	void reInit();
 
 private:
-
-#ifndef ANDROID
 	Mix_Chunk *sound;
 	unsigned char *soundData;
 	int currentChannel;
-
 	bool audioEnabled;
-
 	ConfigFile *myConfig;
 	QString myAppDataPath;
-#endif
 };
 
 #endif
