@@ -1130,6 +1130,7 @@ void startWindowImpl::networkMessage(QString msg)
 void startWindowImpl::networkMessage(unsigned msgId)
 {
 	QString msgText;
+	bool showMsgBox = true;
 
 	switch(msgId) {
 
@@ -1157,15 +1158,41 @@ void startWindowImpl::networkMessage(unsigned msgId)
 		msgText = tr("An error occurred while reporting the game name.");
 	}
 	break;
-	default:
-		;
-		break;
+	case MSG_NET_ADMIN_REMOVE_GAME_ACCEPTED: {
+		msgText = tr("The game was closed.");
+	}
+	break;
+	case MSG_NET_ADMIN_REMOVE_GAME_REJECTED: {
+		msgText = tr("The game could not be closed.");
+	}
+	break;
+	case MSG_NET_ADMIN_BAN_PLAYER_ACCEPTED: {
+		msgText = tr("The player was kicked and banned permanently.");
+	}
+	break;
+	case MSG_NET_ADMIN_BAN_PLAYER_NODB: {
+		msgText = tr("The player was kicked, but could not be banned because it was a guest player.");
+	}
+	break;
+	case MSG_NET_ADMIN_BAN_PLAYER_DBERROR: {
+		msgText = tr("The player was kicked, but could not be banned, \nbecause the nick could not be found in the database");
+	}
+	break;
+	case MSG_NET_ADMIN_BAN_PLAYER_REJECTED: {
+		msgText = tr("The player could not be found.");
+	}
+	break;
+	default: showMsgBox = false;
+	break;
+	}
+
+	if(showMsgBox) {
+		MyMessageBox msgBox(QMessageBox::Information, tr("Server Message"),
+							msgText, QMessageBox::Close, this);
+		//    msgBox.setTextFormat(Qt::RichText);
+		msgBox.exec();
 	}
 
-	MyMessageBox msgBox(QMessageBox::Information, tr("Server Message"),
-						msgText, QMessageBox::Close, this);
-	//    msgBox.setTextFormat(Qt::RichText);
-	msgBox.exec();
 }
 
 
