@@ -376,6 +376,26 @@ ClientThread::SendReportGameName(unsigned reportedGameId)
 	m_ioService->post(boost::bind(&ClientThread::SendSessionPacket, shared_from_this(), packet));
 }
 
+void
+ClientThread::SendAdminRemoveGame(unsigned removeGameId)
+{
+	boost::shared_ptr<NetPacket> packet(new NetPacket);
+	packet->GetMsg()->set_messagetype(PokerTHMessage::Type_AdminRemoveGameMessage);
+	AdminRemoveGameMessage *netRemove = packet->GetMsg()->mutable_adminremovegamemessage();
+	netRemove->set_removegameid(removeGameId);
+	m_ioService->post(boost::bind(&ClientThread::SendSessionPacket, shared_from_this(), packet));
+}
+
+void
+ClientThread::SendAdminBanPlayer(unsigned playerId)
+{
+	boost::shared_ptr<NetPacket> packet(new NetPacket);
+	packet->GetMsg()->set_messagetype(PokerTHMessage::Type_AdminBanPlayerMessage);
+	AdminBanPlayerMessage *netBan = packet->GetMsg()->mutable_adminbanplayermessage();
+	netBan->set_banplayerid(playerId);
+	m_ioService->post(boost::bind(&ClientThread::SendSessionPacket, shared_from_this(), packet));
+}
+
 void
 ClientThread::StartAsyncRead()
 {
