@@ -128,6 +128,14 @@ NetPacketValidator::NetPacketValidator()
 	m_validationMap.insert(make_pair(PokerTHMessage_PokerTHMessageType_Type_ReportGameMessage, ValidateReportGameMessage));
 	m_validationMap.insert(make_pair(PokerTHMessage_PokerTHMessageType_Type_ReportGameAckMessage, ValidateReportGameAckMessage));
 	m_validationMap.insert(make_pair(PokerTHMessage_PokerTHMessageType_Type_ErrorMessage, ValidateErrorMessage));
+	m_validationMap.insert(make_pair(PokerTHMessage_PokerTHMessageType_Type_AdminRemoveGameMessage, ValidateAdminRemoveGameMessage));
+	m_validationMap.insert(make_pair(PokerTHMessage_PokerTHMessageType_Type_AdminRemoveGameAckMessage, ValidateAdminRemoveGameAckMessage));
+	m_validationMap.insert(make_pair(PokerTHMessage_PokerTHMessageType_Type_AdminBanPlayerMessage, ValidateAdminBanPlayerMessage));
+	m_validationMap.insert(make_pair(PokerTHMessage_PokerTHMessageType_Type_AdminBanPlayerAckMessage, ValidateAdminBanPlayerAckMessage));
+	m_validationMap.insert(make_pair(PokerTHMessage_PokerTHMessageType_Type_GameListSpectatorJoinedMessage, ValidateGameListSpectatorJoinedMessage));
+	m_validationMap.insert(make_pair(PokerTHMessage_PokerTHMessageType_Type_GameListSpectatorLeftMessage, ValidateGameListSpectatorLeftMessage));
+	m_validationMap.insert(make_pair(PokerTHMessage_PokerTHMessageType_Type_GameSpectatorJoinedMessage, ValidateGameSpectatorJoinedMessage));
+	m_validationMap.insert(make_pair(PokerTHMessage_PokerTHMessageType_Type_GameSpectatorLeftMessage, ValidateGameSpectatorLeftMessage));
 }
 
 bool
@@ -1145,6 +1153,58 @@ NetPacketValidator::ValidateErrorMessage(const NetPacket &packet)
 	return retVal;
 }
 
+bool
+NetPacketValidator::ValidateAdminRemoveGameMessage(const NetPacket &packet)
+{
+	bool retVal = false;
+	if (packet.GetMsg()->has_adminremovegamemessage()) {
+		const AdminRemoveGameMessage &msg = packet.GetMsg()->adminremovegamemessage();
+		if (msg.removegameid() != 0) {
+			retVal = true;
+		}
+	}
+	return retVal;
+}
+
+bool
+NetPacketValidator::ValidateAdminRemoveGameAckMessage(const NetPacket &packet)
+{
+	bool retVal = false;
+	if (packet.GetMsg()->has_adminremovegameackmessage()) {
+		const AdminRemoveGameAckMessage &msg = packet.GetMsg()->adminremovegameackmessage();
+		if (msg.removegameid() != 0) {
+			retVal = true;
+		}
+	}
+	return retVal;
+}
+
+bool
+NetPacketValidator::ValidateAdminBanPlayerMessage(const NetPacket &packet)
+{
+	bool retVal = false;
+	if (packet.GetMsg()->has_adminbanplayermessage()) {
+		const AdminBanPlayerMessage &msg = packet.GetMsg()->adminbanplayermessage();
+		if (msg.banplayerid() != 0) {
+			retVal = true;
+		}
+	}
+	return retVal;
+}
+
+bool
+NetPacketValidator::ValidateAdminBanPlayerAckMessage(const NetPacket &packet)
+{
+	bool retVal = false;
+	if (packet.GetMsg()->has_adminbanplayerackmessage()) {
+		const AdminBanPlayerAckMessage &msg = packet.GetMsg()->adminbanplayerackmessage();
+		if (msg.banplayerid() != 0) {
+			retVal = true;
+		}
+	}
+	return retVal;
+}
+
 bool
 NetPacketValidator::ValidateGameInfo(const NetGameInfo &gameInfo)
 {
@@ -1167,3 +1227,55 @@ NetPacketValidator::ValidateGameInfo(const NetGameInfo &gameInfo)
 	return retVal;
 }
 
+bool
+NetPacketValidator::ValidateGameListSpectatorJoinedMessage(const NetPacket &packet)
+{
+	bool retVal = false;
+	if (packet.GetMsg()->has_gamelistspectatorjoinedmessage()) {
+		const GameListSpectatorJoinedMessage &msg = packet.GetMsg()->gamelistspectatorjoinedmessage();
+		if (msg.gameid() != 0 && msg.playerid() != 0) {
+			retVal = true;
+		}
+	}
+	return retVal;
+}
+
+bool
+NetPacketValidator::ValidateGameListSpectatorLeftMessage(const NetPacket &packet)
+{
+	bool retVal = false;
+	if (packet.GetMsg()->has_gamelistspectatorleftmessage()) {
+		const GameListSpectatorLeftMessage &msg = packet.GetMsg()->gamelistspectatorleftmessage();
+		if (msg.gameid() != 0 && msg.playerid() != 0) {
+			retVal = true;
+		}
+	}
+	return retVal;
+}
+
+bool
+NetPacketValidator::ValidateGameSpectatorJoinedMessage(const NetPacket &packet)
+{
+	bool retVal = false;
+	if (packet.GetMsg()->has_gamespectatorjoinedmessage()) {
+		const GameSpectatorJoinedMessage &msg = packet.GetMsg()->gamespectatorjoinedmessage();
+		if (msg.gameid() != 0 && msg.playerid() != 0) {
+			retVal = true;
+		}
+	}
+	return retVal;
+}
+
+bool
+NetPacketValidator::ValidateGameSpectatorLeftMessage(const NetPacket &packet)
+{
+	bool retVal = false;
+	if (packet.GetMsg()->has_gamespectatorleftmessage()) {
+		const GameSpectatorLeftMessage &msg = packet.GetMsg()->gamespectatorleftmessage();
+		if (msg.gameid() != 0 && msg.playerid() != 0) {
+			retVal = true;
+		}
+	}
+	return retVal;
+}
+
