@@ -146,16 +146,16 @@ public:
 		LOG_MSG("Successfully connected to database.");
 	}
 
-	virtual void ConnectFailed(const string &error) {
+	virtual void ConnectFailed(string error) {
 		LOG_ERROR("DB connect error: " << error);
 	}
 
-	virtual void QueryError(const std::string &error) {
+	virtual void QueryError(string error) {
 		LOG_ERROR("DB query error: " << error);
 	}
 
-	virtual void PlayerLoginSuccess(unsigned requestId, const DBPlayerData &dbPlayerData) {
-		m_server.UserValid(requestId, dbPlayerData);
+	virtual void PlayerLoginSuccess(unsigned requestId, boost::shared_ptr<DBPlayerData> dbPlayerData) {
+		m_server.UserValid(requestId, *dbPlayerData);
 	}
 
 	virtual void PlayerLoginFailed(unsigned requestId) {
@@ -199,6 +199,18 @@ public:
 		m_server.SendReportGameResult(requestId, replyId, false);
 	}
 
+	virtual void PlayerAdminList(unsigned /*requestId*/, std::list<DB_id> adminList) {
+		m_server.GetBanManager().SetAdminPlayerIds(adminList);
+	}
+
+	virtual void BlockPlayerSuccess(unsigned requestId, unsigned replyId) {
+		m_server.SendAdminBanPlayerResult(requestId, replyId, true);
+	}
+
+	virtual void BlockPlayerFailed(unsigned requestId, unsigned replyId) {
+		m_server.SendAdminBanPlayerResult(requestId, replyId, false);
+	}
+
 private:
 	ServerLobbyThread &m_server;
 };
@@ -242,6 +254,7 @@ ServerLobbyThread::Init(const string &logDir)
 		m_serverConfig.readConfigString("DBServerPassword"),
 		m_serverConfig.readConfigString("DBServerDatabaseName"),
 		m_serverConfig.readConfigString("DBServerEncryptionKey"));
+	m_database->AsyncQueryAdminPlayers(0);
 
 	GetBanManager().InitGameNameBadWordList(m_serverConfig.readConfigStringList("GameNameBadWordList"));
 }
@@ -511,6 +524,20 @@ ServerLobbyThread::HandleChatRequest(boost::shared_ptr<SessionData> session, con
 	HandleNetPacketChatRequest(session, chatRequest);
 }
 
+void
+ServerLobbyThread::HandleAdminRemoveGame(boost::shared_ptr<SessionData> session, const AdminRemoveGameMessage &removeGame)
+{
+	// An admin within a game sent a remove game message.
+	HandleNetPacketAdminRemoveGame(session, removeGame);
+}
+
+void
+ServerLobbyThread::HandleAdminBanPlayer(boost::shared_ptr<SessionData> session, const AdminBanPlayerMessage &banPlayer)
+{
+	// An admin within a game sent a ban player message.
+	HandleNetPacketAdminBanPlayer(session, banPlayer);
+}
+
 bool
 ServerLobbyThread::KickPlayerByName(const std::string &playerName)
 {
@@ -926,6 +953,10 @@ ServerLobbyThread::HandlePacket(boost::shared_ptr<SessionData> session, boost::s
 				HandleNetPacketReportGame(session, packet->GetMsg()->reportgamemessage());
 			} else if (packet->GetMsg()->messagetype() == PokerTHMessage::Type_LeaveGameRequestMessage) {
 				// Ignore "leave game" in this state.
+			} else if (packet->GetMsg()->messagetype() == PokerTHMessage::Type_AdminRemoveGameMessage) {
+				HandleNetPacketAdminRemoveGame(session, packet->GetMsg()->adminremovegamemessage());
+			} else if (packet->GetMsg()->messagetype() == PokerTHMessage::Type_AdminBanPlayerMessage) {
+				HandleNetPacketAdminBanPlayer(session, packet->GetMsg()->adminbanplayermessage());
 			} else {
 				SessionError(session, ERR_SOCK_INVALID_STATE);
 			}
@@ -1074,6 +1105,10 @@ ServerLobbyThread::HandleNetPacketAuthClientResponse(boost::shared_ptr<SessionDa
 			GetSender().Send(session, packet);
 			// The last message is only for server verification.
 			// We are done now, the user has logged in.
+			boost::shared_ptr<PlayerData> tmpPlayerData = session->GetPlayerData();
+			if (GetBanManager().IsAdminPlayer(tmpPlayerData->GetDBId())) {
+				session->GetPlayerData()->SetRights(PLAYER_RIGHTS_ADMIN);
+			}
 			CheckAvatarBlacklist(session);
 		} else
 			SessionError(session, ERR_NET_INVALID_PASSWORD);
@@ -1460,6 +1495,71 @@ ServerLobbyThread::HandleNetPacketReportGame(boost::shared_ptr<SessionData> sess
 	}
 }
 
+void
+ServerLobbyThread::HandleNetPacketAdminRemoveGame(boost::shared_ptr<SessionData> session, const AdminRemoveGameMessage &removeGame)
+{
+	GameMap::iterator pos = m_gameMap.find(removeGame.removegameid());
+
+	// Create Ack-Packet.
+	boost::shared_ptr<NetPacket> packet(new NetPacket);
+	packet->GetMsg()->set_messagetype(PokerTHMessage::Type_AdminRemoveGameAckMessage);
+	AdminRemoveGameAckMessage *netRemoveAck = packet->GetMsg()->mutable_adminremovegameackmessage();
+	netRemoveAck->set_removegameid(removeGame.removegameid());
+
+	// Check whether game id is valid and whether the player is an admin.
+	if (pos != m_gameMap.end() && session->GetPlayerData() && GetBanManager().IsAdminPlayer(session->GetPlayerData()->GetDBId())) {
+		LOG_ERROR("Player " << session->GetPlayerData()->GetName() << "(" << session->GetPlayerData()->GetDBId() << ") removes game '" << pos->second->GetName() << "'");
+		InternalRemoveGame(pos->second);
+		netRemoveAck->set_removegameresult(AdminRemoveGameAckMessage::gameRemoveAccepted);
+	} else {
+		netRemoveAck->set_removegameresult(AdminRemoveGameAckMessage::gameRemoveInvalid);
+	}
+	GetSender().Send(session, packet);
+}
+
+void
+ServerLobbyThread::HandleNetPacketAdminBanPlayer(boost::shared_ptr<SessionData> session, const AdminBanPlayerMessage &banPlayer)
+{
+	// Create Ack-Packet.
+	boost::shared_ptr<NetPacket> packet(new NetPacket);
+	packet->GetMsg()->set_messagetype(PokerTHMessage::Type_AdminBanPlayerAckMessage);
+	AdminBanPlayerAckMessage *netBanAck = packet->GetMsg()->mutable_adminbanplayerackmessage();
+	netBanAck->set_banplayerid(banPlayer.banplayerid());
+
+	if (session && session->GetPlayerData() && GetBanManager().IsAdminPlayer(session->GetPlayerData()->GetDBId())) {
+
+		boost::shared_ptr<SessionData> tmpSession = m_sessionManager.GetSessionByUniquePlayerId(banPlayer.banplayerid());
+		if (!tmpSession) {
+			tmpSession = m_gameSessionManager.GetSessionByUniquePlayerId(banPlayer.banplayerid());
+		}
+		boost::shared_ptr<PlayerData> tmpPlayer;
+		if (tmpSession) {
+			tmpPlayer = tmpSession->GetPlayerData();
+		}
+		if (tmpPlayer && !GetBanManager().IsAdminPlayer(tmpPlayer->GetDBId())) {
+			// Ban the player's IP address for 24 hours.
+			GetBanManager().BanIPAddress(tmpSession->GetClientAddr(), 24);
+			// Kick the player.
+			RemovePlayer(tmpPlayer->GetUniqueId(), ERR_NET_PLAYER_KICKED);
+			// Permanently ban the player in the database.
+			if (tmpPlayer->GetDBId() != DB_ID_INVALID) {
+				LOG_ERROR("Player " << session->GetPlayerData()->GetName() << "(" << session->GetPlayerData()->GetDBId() 
+					<< ") bans player " << tmpPlayer->GetName() << "(" << tmpPlayer->GetDBId() 
+					<< ") who has IP " << tmpSession->GetClientAddr());
+				GetDatabase()->AsyncBlockPlayer(session->GetPlayerData()->GetUniqueId(), tmpPlayer->GetUniqueId(), tmpPlayer->GetDBId(), 0, 4);
+				netBanAck->set_banplayerresult(AdminBanPlayerAckMessage::banPlayerPending);
+			} else {
+				netBanAck->set_banplayerresult(AdminBanPlayerAckMessage::banPlayerNoDB);
+			}
+		} else {
+			netBanAck->set_banplayerresult(AdminBanPlayerAckMessage::banPlayerInvalid);
+		}
+	} else {
+		netBanAck->set_banplayerresult(AdminBanPlayerAckMessage::banPlayerInvalid);
+	}
+	GetSender().Send(session, packet);
+}
+
 void
 ServerLobbyThread::AuthChallenge(boost::shared_ptr<SessionData> session, const string &secret)
 {
@@ -1649,6 +1749,22 @@ ServerLobbyThread::SendReportGameResult(unsigned byPlayerId, unsigned reportedGa
 	}
 }
 
+void
+ServerLobbyThread::SendAdminBanPlayerResult(unsigned byPlayerId, unsigned reportedPlayerId, bool success)
+{
+	boost::shared_ptr<SessionData> session = m_sessionManager.GetSessionByUniquePlayerId(byPlayerId);
+	if (!session)
+		session = m_gameSessionManager.GetSessionByUniquePlayerId(byPlayerId);
+	if (session) {
+		boost::shared_ptr<NetPacket> packet(new NetPacket);
+		packet->GetMsg()->set_messagetype(PokerTHMessage::Type_AdminBanPlayerAckMessage);
+		AdminBanPlayerAckMessage *netBanAck = packet->GetMsg()->mutable_adminbanplayerackmessage();
+		netBanAck->set_banplayerid(reportedPlayerId);
+		netBanAck->set_banplayerresult(success ? AdminBanPlayerAckMessage::banPlayerAccepted : AdminBanPlayerAckMessage::banPlayerDBError);
+		GetSender().Send(session, packet);
+	}
+}
+
 void
 ServerLobbyThread::UserBlocked(unsigned playerId)
 {
